@@ -4,7 +4,7 @@ require Exporter;
 @EXPORT_OK = qw/to_singular/;
 use warnings;
 use strict;
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Irregular plurals.
 
@@ -89,7 +89,7 @@ my %ies;
 # and "sandwiches". $1 is a capture which contains the part of the
 # word which should be kept in a substitution.
 
-my $es_re = qr/(ch|sh)es$/;
+my $es_re = qr/([^aeiou]s|ch|sh)es$/;
 
 # See documentation below.
 
